<?php
	/*
	 * development debug functions
	 */
	if(!function_exists('__d')) {
		function __d($o, $msg = null) {
			$f = fopen ('/tmp/debug.shopware', 'a+');

			if ($msg)
				fwrite ($f, "$msg:\n");

			fwrite ($f, print_r ($o, true));
			fwrite ($f, "\n");
			fclose ($f);
		}
	}

	if(!function_exists('__debug')) {
		function __debug($msg) {
			echo "<pre>";
			print_r($msg);
			echo "</pre>";
			echo "<hr />";
		}
	}

	class Shopware_Plugins_Frontend_BuiswCleverReach_Bootstrap extends Shopware_Components_Plugin_Bootstrap {
		const NAME = 'BuiswCleverReach';

		/*
		 * register plugin namespaces
		 */
		static public function registerNamespace() {
			static $done = false;

			if(!$done) {
				$done = true;
				Shopware()->Loader()->registerNamespace('Shopware', dirname(__FILE__) . '/');
			}
		}

		/*
		 * install plugin
		 */
		public function install() {
			if(!$this->assertVersionGreaterThen("3.5.5"))
				throw new Enlight_Exception("This Plugin needs min shopware 3.5.5");

			$this->createForm();
			$this->createMenu();
			$this->createEvents();
			$this->createHooks();
			$this->createTables();

			return parent::install();
		}

		/*
		 * uninstall plugin
		 */
		public function uninstall() {
			$sqls[] = 'DROP TABLE IF EXISTS s_bui_plg_cleverreach_assignments';

			foreach($sqls as $sql)
				Shopware()->Db()->exec($sql);

			return parent::uninstall();
		}

		/*
		 * enable plugin
		 */
		public function enable() {
			return parent::enable();
		}

		/*
		 * disable plugin
		 */
		public function disable() {
			return parent::disable();
		}

		/*
		 * get main info for this plugin
		 */
		public function getInfo() {
			return include(dirname(__FILE__) . '/Meta.php');
		}

		/*
		 * plugin version
		 */
		public function getVersion() {
			return '1.0.1';
		}

		/* 
		 * plugin name
		 */
		public function getName() {
			return "CleverReach";
		}

		/*
		 * create plugin config form
		 */
		protected function createForm() {
			$form = $this->Form();
			$form->setElement('text', 'api_key', array ('label' => 'API-Key', 'value' => '', 'scope'=> Shopware_Components_Form::SCOPE_SHOP));
			$form->setElement('text', 'wsdl_url', array ('label' => 'WSDL-Url', 'value' => 'http://api.cleverreach.com/soap/interface_v5.1.php?wsdl', 'scope'=> Shopware_Components_Form::SCOPE_SHOP));
			$form->setElement('text', 'export_limit', array ('label' => 'Export-Limit pro Step (max. 50)', 'value' => '50 ', 'scope'=> Shopware_Components_Form::SCOPE_SHOP));

			// Beispiel 1 - Beispiel von Shopware - Funktioniert nicht
			/*$form->setElement('text', 'configkey', array('label'=>'Ihr Konfigurationsschl&uuml;ssel', 'value'=>'xyz','attributes'=>array("uniqueId"=>'configkey')));
			$form->setElement('button', 'test10', array('label'=>'Zugangsdaten pruefen','attributes'=>array(
			'handler'=>'function (){
				console.log (232);
			}',
			'text' => 'Start',
			'xtype' => 'button')));*/

			// Beispiel 2 - Beispiel von Shopware auf meine wünsche abgeändert - Funktioniert nicht
			/*$form->setElement('button', 'register_products_search', array('label'=>'Produktsuche in CleverReach aktivieren','attributes'=>array(
				'handler' => 'function (){
						console.log(33);
					}',
				'text' => 'Aktivieren',
				'xtype' => 'button')));*/

			// Beispiel 3 - neue Funktion - lädt den admin neu wenn man den button drückt
			// $form->setElement('controllerbutton', 'Test Action', array('label'=>'Config aufrufen','value'=>'','attributes'=>array('controller'=>'snippet','action'=>'skeleton')))
			$form->save();
		}

		/*
		 * create menu
		 */
		protected function createMenu() {
			$parent = $this->Menu()->findOneBy('label', 'Marketing');

			$item = $this->createMenuItem(array(
				'label' => 'CleverReach',
				'onclick' => '',
				'class' => 'ico2 cleverreachicon',
				'active' => 1,
				'position' => 10,
				'parent' => $parent,
				'style' => 'background-position: 5px 5px;',
				'pluginID' => $this->getId()
			));

			$this->Menu()->addItem($item);

			$this->Menu()->save();

			$parent = $this->Menu()->findOneBy('label', 'CleverReach');

			$items[] = $this->createMenuItem(array(
				'label' => 'Anmelden',
				'onclick' => 'openAction(\'BuiswCleverReach\' , \'Register\');',
				'class' => 'ico2 cleverreachicon',
				'active' => 1,
				'position' => 10,
				'parent' => $parent,
				'style' => 'background-position: 5px 5px;',
				'pluginID' => $this->getId()
			));

			$items[] = $this->createMenuItem(array(
				'label' => 'Listen-Zuordnung',
				'onclick' => 'openAction(\'BuiswCleverReach\' , \'Lists\');',
				'class' => 'ico2 cleverreachicon',
				'active' => 1,
				'position' => 10,
				'parent' => $parent,
				'style' => 'background-position: 5px 5px;',
				'pluginID' => $this->getId()
			));

			$items[] = $this->createMenuItem(array(
				'label' => 'Erst-Export',
				'onclick' => 'openAction(\'BuiswCleverReach\' , \'Export\');',
				'class' => 'ico2 cleverreachicon',
				'active' => 1,
				'position' => 10,
				'parent' => $parent,
				'style' => 'background-position: 5px 5px;',
				'pluginID' => $this->getId()
			));

			$items[] = $this->createMenuItem(array(
				'label' => 'Produkt-Suche aktivieren',
				'onclick' => 'openAction(\'BuiswCleverReach\' , \'RegisterProductsSearch\');',
				'class' => 'ico2 cleverreachicon',
				'active' => 1,
				'position' => 10,
				'parent' => $parent,
				'style' => 'background-position: 5px 5px;',
				'pluginID' => $this->getId()
			));

			foreach ($items as $item)
				$this->Menu()->addItem($item);

			$this->Menu()->save();
		}

		/*
		 * create events
		 */
		protected function createEvents() {
			$events[] = $this->createEvent('Enlight_Controller_Action_PostDispatch_Backend_Index', 'onPostDispatch');
			$events[] = $this->createEvent('Enlight_Controller_Dispatcher_ControllerPath_Backend_BuiswCleverReach', 'onGetControllerPathBackend');
			$events[] = $this->createEvent('Enlight_Controller_Action_PostDispatch', 'onPostDispatchFrontend');
			$events[] = $this->createEvent('Enlight_Controller_Dispatcher_ControllerPath_Frontend_BuiswCleverReach', 'onGetControllerPathFrontend');

			foreach($events as $event)
				$this->subscribeEvent($event);
		}

		/*
		 * create hooks
		 */
		protected function createHooks() {
			$hooks[] = $this->createHook('sAdmin', 'sNewsletterSubscription', 'after_sNewsletterSubscription', Enlight_Hook_HookHandler::TypeAfter, 0);
			$hooks[] = $this->createHook('sAdmin', 'sSaveRegisterNewsletter', 'after_sSaveRegisterNewsletter', Enlight_Hook_HookHandler::TypeAfter, 0);
			$hooks[] = $this->createHook('sAdmin', 'sUpdateNewsletter', 'after_sUpdateNewsletter', Enlight_Hook_HookHandler::TypeAfter, 0);
			$hooks[] = $this->createHook('Shopware_Controllers_Frontend_Checkout', 'finishAction', 'after_finishAction', Enlight_Hook_HookHandler::TypeAfter, 0);

			foreach($hooks as $hook)
				$this->subscribeHook($hook);
		}

		/*
		 * create DB Tables
		 */
		protected function createTables() {
			$sqls[] = 'CREATE TABLE IF NOT EXISTS s_bui_plg_cleverreach_assignments (
				shop INT(11) NOT NULL,
				customergroup INT(11) NOT NULL,
				listid INT(11) DEFAULT NULL,
				PRIMARY KEY (shop, customergroup)
			)';

			foreach($sqls as $sql)
				Shopware()->Db()->exec($sql);
		}

		/*
		 * Include the CleverReach image to the Stylesheet
		 */
		static function onPostDispatch(Enlight_Event_EventArgs $args) {
			self::registerNamespace();

			$response = $args->getSubject()->Response();

			if($response->isException())
				return;

			$view = $args->getSubject()->View();
			$view->addTemplateDir(dirname(__FILE__) . '/');
			$icon  = "http://" . Shopware()->Config()->basepath . '/engine/Shopware/Plugins/Community/Frontend/BuiswCleverReach/images/cleverreach.png';
			$style = '<style type="text/css">a.cleverreachicon { background: url(' . $icon . ') no-repeat 0px 0px transparent;}</style>';
			$view->extendsBlock('backend_index_css', $style, 'append');
		}

		/*
		 * Backend Script for CleverReach Menu Forms
		 */
		public static function onGetControllerPathBackend(Enlight_Event_EventArgs $args) {
			self::registerNamespace();

			return dirname(__FILE__) . '/CleverReachBackend.php';
		}

		/*
		 * set conversation tracking id from newsletter-mail-link
		 */
		public static function onPostDispatchFrontend(Enlight_Event_EventArgs $args) {
			self::registerNamespace();

			if($_GET['crmailing'])
				$_SESSION['Shopware']['BuiswCleverReach_mailingID'] = $_GET['crmailing'];
		}

		/*
		 * get path for CleverReach products search
		 */
		public static function onGetControllerPathFrontend(Enlight_Event_EventArgs $args) {
			self::registerNamespace();

			return dirname(__FILE__).'/Controllers/Frontend/BuiswCleverReach.php';
		}

		/*
		 * 1. case: frontend content form
		 */
		public static function after_sNewsletterSubscription(Enlight_Hook_HookArgs $args) {
			self::registerNamespace();

			$params = $args->getArgs(); // 0 => email (xxxxx@domain.tld) | 1 => UNsubscribe status (true / false) | 2 => groupID (null)

			$data = array();
			$data['email'] = $params[0];
			$data['status'] = !$params[1];

			Shopware_Controllers_Frontend_BuiswCleverReach::init('content_form', $data);
		}

		/*
		 * Not used => no checkbox for newsletter subscription in register formular
		 */
		public static function after_sSaveRegisterNewsletter(Enlight_Hook_HookArgs $args) {
			self::registerNamespace();
		}

		/*
		 * 1. case: logged in user -> My Account => newsletter settings
		 * 2. case: in order process klicked the checkbox for the newsletter
		 */
		public static function after_sUpdateNewsletter(Enlight_Hook_HookArgs $args) {
			self::registerNamespace();

			$params = $args->getArgs(); // 0 => status (true/false) | 1 => email (xxxxx@domain.tld) | 2 => customer (true/false) <= ist immer true, warum auch immer ...

			$data = array();
			$data['email'] = $params[1];
			$data['status'] = $params[0];

			Shopware_Controllers_Frontend_BuiswCleverReach::init('account', $data);
		}

		/*
		 * send order to cleverreach
		 */
		public static function after_finishAction(Enlight_Hook_HookArgs $args) {
			self::registerNamespace();

			$data = array();

			Shopware_Controllers_Frontend_BuiswCleverReach::init('checkout_finish', $data);
		}
	}
?>