<?php
	class Shopware_Controllers_Frontend_BuiswCleverReach extends Enlight_Controller_Action {
		/*
		 * init class
		 */
		public function init($mode, $params) {
			$order = array();

			switch($mode) {
				case 'content_form':
					$data = self::prepareDataFromContentform($params['status']);
					break;
				case 'account':
					$data = self::prepareDataFromAccount($params['status']);
					break;
				case 'checkout_finish':
					$order = self::prepareDataFromCheckoutFinish($params);

					$status = ($_POST['sNewsletter'] == "1") ? "1" : "0";

					$data = self::prepareDataFromAccount($status);
					
					break;
				default:
					return;
			}

			self::sendToCleverReach($params['status'], $params['email'], $data, $order);
		}

		/*
		 * prepare user data from content form
		 */
		protected function prepareDataFromContentform($status) {
			if($_POST['salutation'])
				$data['anrede'] = ($_POST['salutation'] == 'ms') ? 'Frau' : 'Herr';

			if($_POST['firstname'])
				$data['vorname'] = $_POST['firstname'];

			if($_POST['lastname'])
				$data['nachname'] = $_POST['lastname'];

			if($_POST['street'] || $_POST['streetnumber'])
				$data['strasse'] = $_POST['street'] . ' ' . $_POST['streetnumber'];

			if($_POST['zipcode'])
				$data['postleitzahl'] = $_POST['zipcode'];

			if($_POST['city'])
				$data['stadt'] = $_POST['city'];

			$data['newsletter'] = $status;

			return $data;
		}

		/*
		 * prepare user data from user account
		 */
		protected function prepareDataFromAccount($status) {
			$customer = Shopware()->System()->sMODULES['sAdmin']->sGetUserData();

			$data['firma'] = $customer['billingaddress']['company'];
			$data['anrede'] = ($customer['billingaddress']['salutation'] == 'ms') ? 'Frau' : 'Herr';
			$data['vorname'] = $customer['billingaddress']['firstname'];
			$data['nachname'] = $customer['billingaddress']['lastname'];
			$data['strasse'] = $customer['billingaddress']['street'] . ' ' . $customer['billingaddress']['streetnumber'];
			$data['postleitzahl'] = $customer['billingaddress']['zipcode'];
			$data['stadt'] = $customer['billingaddress']['city'];
			$data['land'] = Shopware()->Db()->fetchOne('SELECT countryname FROM s_core_countries WHERE id='.$customer['billingaddress']['countryID']);

			if($status == 0) {
				$count = Shopware()->Db()->fetchOne('SELECT COUNT(*) FROM s_campaigns_mailaddresses WHERE email="'.$customer['additional']['user']['email'].'"');

				if($count == "0")
					$status = "0";
				else
					$status = "1";
			}

			$data['newsletter'] = $status;

			return $data;
		}

		/*
		 * prepare data from finished order
		 */
		protected function prepareDataFromCheckoutFinish(&$params) {
			$order = array();
			$customer = Shopware()->System()->sMODULES['sAdmin']->sGetUserData();

			$order = self::getOrderData();
			$params['email'] = $customer['additional']['user']['email'];
			$params['status'] = true;

			return $order;
		}

		/*
		 * get order data
		 */
		protected function getOrderData() {
			$orderData = array();
			$orderDataProduct = array();

			$order = $_SESSION['Shopware']['sOrderVariables'];
			$orderID = $order['sOrderNumber'];

			foreach($order['sBasket']['content'] as $orderProduct) {
				$orderDataProduct = array();

				$orderDataProduct['purchase_date'] = time();
				$orderDataProduct['order_id'] = $orderID;
				$orderDataProduct['product'] = utf8_encode($orderProduct['articlename']);
				$orderDataProduct['product_id'] = $orderProduct['articleID'];
				$orderDataProduct['quantity'] = $orderProduct['quantity'];
				$orderDataProduct['price'] = str_replace(',', '.', $orderProduct['price']);
				$orderDataProduct['source'] = 'Shopware';

				if($_SESSION['Shopware']['BuiswCleverReach_mailingID'])
					$orderDataProduct['mailings_id'] = $_SESSION['Shopware']['BuiswCleverReach_mailingID'];

				$orderData[] = $orderDataProduct;
			}

			return $orderData;
		}

		/*
		 * send data to CleverReach
		 */
		protected function sendToCleverReach($status, $email, $data, $order) {
			$config = Shopware()->Plugins()->Frontend()->BuiswCleverReach()->Config(); // api_key | wsdl_url | export_limit
			$listID = self::getListID($order);

			$api = new SoapClient($config->wsdl_url);

			if($status == true) {
				// add to newsletter
				$attributesData = array();

				self::addAttributes($api, $config->api_key, $listID);

				foreach($data as $dataKey => $dataValue)
					$attributesData[] = array('key' => $dataKey, 'value' => utf8_encode($dataValue));

				$receiver = array(
					'email' => $email,
					'attributes'=> $attributesData
				);

				if(count($order) > 0)
					$receiver['orders'] = $order;

				$response = $api->receiverAdd($config->api_key, $listID, $receiver);

				if($response->status == "ERROR" && ($response->statuscode == "50" || $response->statuscode == "55")) {
					$receiver['activated'] = time();
					$receiver['deactivated'] = "0";
					$response = $api->receiverUpdate($config->api_key, $listID, $receiver);
				}
			} else {
				// deacitvate from newsletter
				$response = $api->receiverSetInactive($config->api_key, $listID, $email);
			}
		}

		/*
		 * get list-ID assigned to the customer
		 */
		protected function getListID($order) {
			$shop = Shopware()->Shop()->getId();
			$customer = Shopware()->System()->sMODULES['sAdmin']->sGetUserData();

			if(!$customer['additional']['user']['id'])
				$customergroup = 100;
			else {
				if(count($order) > 0) {
					if($customer['additional']['user']['newsletter'] == 0)
						$customergroup = 0;
					else
						$customergroup = Shopware()->Db()->fetchOne('SELECT id FROM s_core_customergroups WHERE groupkey="'.$customer['additional']['user']['customergroup'].'"');
				} else
					$customergroup = Shopware()->Db()->fetchOne('SELECT id FROM s_core_customergroups WHERE groupkey="'.$customer['additional']['user']['customergroup'].'"');
			}

			$listID = Shopware()->Db()->fetchOne('SELECT listid FROM s_bui_plg_cleverreach_assignments WHERE shop='.$shop.' AND customergroup='.$customergroup);

			return $listID;
		}

		/*
		 * set group attributes to the newsletter-group in CleverReach
		 */
		protected function addAttributes($api, $apiKey, $listID) {
			$api->groupAttributeAdd($apiKey, $listID, "Firma", "text", '');
			$api->groupAttributeAdd($apiKey, $listID, "Anrede", "gender", '');
			$api->groupAttributeAdd($apiKey, $listID, "Vorname", "text", '');
			$api->groupAttributeAdd($apiKey, $listID, "Nachname", "text", '');
			$api->groupAttributeAdd($apiKey, $listID, "Strasse", "text", '');
			$api->groupAttributeAdd($apiKey, $listID, "Postleitzahl", "text", '');
			$api->groupAttributeAdd($apiKey, $listID, "Stadt", "text", '');
			$api->groupAttributeAdd($apiKey, $listID, "Land", "text", '');
			$api->groupAttributeAdd($apiKey, $listID, "Newsletter", "text", '');
		}

		public function searchProductsAction() {
			Shopware()->Plugins()->Controller()->ViewRenderer()->setNoRender();

			switch($_POST["get"]) {
				case "filter":
					$filters = false;
					$filter = false;

					$filter = false;
					$filter->name = "Produkt";	
					$filter->description = "";
					$filter->required = false;
					$filter->query_key = "product";	
					$filter->type = "input";			
					$filters[]=$filter;

					echo json_encode($filters);
					exit(0);
					break;
				case 'search':
					$items = false;

					$items->settings->type="product";
					$items->settings->link_editable = false;
					$items->settings->link_text_editable = false;
					$items->settings->image_size_editable = false;

					$search = $_POST['product'];

					$product_ids = Shopware()->Db()->fetchCol('SELECT id FROM s_articles WHERE name LIKE "%'.$search.'%" OR description LIKE "%'.$search.'%" OR description_long LIKE "%'.$search.'%"');

					if(count($product_ids) == 0)
						exit(0);

					foreach($product_ids as $product_id) {
						$out = false;

						$product = Shopware()->System()->sMODULES['sArticles']->sGetArticleById($product_id);

						$url = 'http://' . Shopware()->Config()->basepath . '/' . $product['linkDetails'];

						$out->title = $product['articleName'];
						$out->description = $product['description_long'];
						$out->image = $product['image']['src'][2];
						$out->price = $product['price'];
						$out->url = $url;

						$items->items[] = $out;
					}

					echo json_encode($items);
					exit(0);
					break;
			}
		}
	}
?>